from setuptools import setup

setup(name='em_distributions',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['em_distributions'],
      author = 'Emilio Mantilla',
      author_email = 'emiliomantilla25@gmail.com',
      zip_safe=False)
